#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyramid.view import view_config
from pyams_form.form import AJAXEditForm
from pyams_i18n.interfaces import II18nManager
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.layer import IPyAMSLayer
from pyams_skin.viewlet.menu import MenuItem
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces

# import packages
from z3c.form import field

from pyams_i18n import _


#
# Content languages
#

@viewlet_config(name='languages.menu', context=II18nManager, layer=IAdminLayer,
                manager=IPropertiesMenu, permission='system.view', weight=11)
class I18nManagerLanguagesMenu(MenuItem):
    """I18n manager languages menu"""

    label = _("Languages...")
    icon_class = 'fa-flag'

    url = 'languages.html'
    modal_target = True


@pagelet_config(name='languages.html', context=II18nManager, layer=IPyAMSLayer, permission='system.view')
class I18nManagerLanguagesEditForm(AdminDialogEditForm):
    """I18n manager languages edit form"""

    legend = _("Content languages")

    fields = field.Fields(II18nManager)
    ajax_handler = 'languages.json'
    edit_permission = 'system.view'


@view_config(name='languages.json', context=II18nManager, request_type=IPyAMSLayer,
             permission='system.view', renderer='json', xhr=True)
class I18nManagerLanguagesAJAXEditForm(AJAXEditForm, I18nManagerLanguagesEditForm):
    """I18n manager languages edit form, JSON renderer"""
